# jag
Simple, standalone http server.

Jag is a bootleg version of python Flask (not a wrapper. Written from scratch)
It was created specifically to spread mental retardation across the universe.
It's platform-independent (tested on Windows, Linux and Android, fuck Apple)

Please read the docs at https://mrkleiner.github.io/source_tricks/?lt=85c456e8